clear;
close all ;

global kr sir sib T;

% Maximum maturity

T=30;

% Risk aversion

a = 3*6.77;
% a = 3*18.75;

% QE as % of GDP

DS = -0.12;

% Forward guidance

Drbar = -0.04;

% Mean reversion of one-off shock

kth = 0.1;
krb = 0.2;

% rbar and theta0 (to compute correlation with SDF)

rbar = 0.048;
ath0 = 289;


% Annual yield changes, T-bills excluded

% Values (dal,dth) and (kb,aal,ath) minimizing FitVolume and SSR, respectively

% % Nov 1985 - Jan 2020, volatility level and change, correlation change, averaged across maturities
% kr = 0.125;
% sir = 0.0146^2;
% sib = 0.0146^2;
% % % Solution for dal that is optimal for volume in inelastic case
% % dal = 0.257;
% % dth = 0.666;
% % kb = 0.054;
% % aal = 23;
% % ath = 178;
% % Solution for dal, obtained by iterating from volume in inelastic case, and only solution that yields decreasing volume after the hump as function of maturity
% dal = 0.297; % FitVolume = [ -0.0155 -0.0068 ]
% dth = 0.307;
% kb = 0.053;
% aal = 35.3;
% ath = 3155.2;

% % Nov 1985 - Jan 2020, volatility level, FBCS, correlation change, averaged across maturities
% kr = 0.125;
% sir = 0.0141^2;
% sib = 0.0141^2;
% % % Solution for dal that is optimal for volume in inelastic case
% % dal = 0.257;
% % dth = 0.666;
% % kb = 0.1785;
% % aal = 5.25;
% % ath = 175.9;
% % Solution for dal, obtained by iterating from volume in inelastic case, and only solution that yields decreasing volume after the hump as function of maturity
% dal = 0.347; % FitVolume = [ -0.0195 -0.00789 ]
% dth = 0.357;
% kb = 0.1705;
% aal = 12.6;
% ath = 4740.7;

% Jan 1999 - Jan 2020, volatility level and change, correlation change, averaged across maturities
kr = 0.24;
sir = 0.0159^2;
sib = 0.0159^2;
% % Solution for dal this is optimal for volume in inelastic case
% dal = 0.257;
% dth = 0.666;
% kb = 0.128;
% aal = 61;
% ath = 373;
% Solution for dal, obtained by iterating from volume in inelastic case, and only solution that yields decreasing volume after the hump as function of maturity
dal = 0.269; % FitVolume = [ -0.000358 -0.006243 ]
dth = 0.279;
kb = 0.1265;     
aal = 80.25;
ath = 5305.8;

% % Jan 1999 - Jan 2020, volatility level, FBCS, correlation change, averaged across maturities
% kr = 0.24;
% sir = 0.0152^2;
% sib = 0.0152^2;
% % % Solution for dal that is optimal for volume in inelastic case
% % dal = 0.257; 
% % dth = 0.666;
% % kb = 0.386;
% % aal = 20.6;
% % ath = 382;
% % Solution for dal, obtained by iterating from volume in inelastic case, and only solution that yields decreasing volume after the hump as function of maturity
% dal = 0.34; % FitVolume = [ -0.0026 -0.0133 ]
% dth = 0.35;
% kb = 0.315;
% aal = 48;
% ath = 9119.5;


% Solve for M

% Initial condition (aal=0)

options=optimset('MaxFunEvals',100000,'MaxIter',10000);

Hkbloc = @(x)Hkb(x,kb,aal,ath,dal,dth);
                      
[hkb,fval,exitflag] = fsolve(Hkbloc,kb,options);

ZAb = sir*ath*Hint(kr,dal,dth)/(1+sir*aal*(Fint(kr,kr,dal)-Fint(kr,hkb,dal))/(hkb-kr));

M011 = kr+sir*aal*Fint(kr,kr,dal);

M012 = sib*aal*ZAb*(Fint(kr,kr,dal)-Fint(kr,hkb,dal))/(hkb-kr);

M021 = -sir*(ath*Hint(kr,dal,dth)-aal*ZAb*(Fint(kr,kr,dal)-Fint(kr,hkb,dal))/(hkb-kr));

M022 = kb-sib*ZAb*(ath*(Hint(kr,dal,dth)-Hint(hkb,dal,dth))-aal*ZAb*(Fint(kr,kr,dal)+Fint(hkb,hkb,dal)-2*Fint(kr,hkb,dal))/(hkb-kr))/(hkb-kr);      


% Solve non-linear system

M0 = [ M011 M012 M021 M022 ];

Mmatloc = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(Mmatloc,M0,options);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

% Display

disp(['Eigenvalues     = ',num2str(eigvalues)]);
disp(['Eigenvector 1     = ',num2str(eigvector1)]);    
disp(['Eigenvector 2     = ',num2str(eigvector2)]); 

% Curves

% coefs in Ar

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

% coefs in Ab

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;


% Fama-Bliss

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Dn=3;
Dt=0.5*(Dn-1);

for n=Dn+1 : 1 : Ttwo
    n1=n-Dn+1;
    FBnum(1,n-Dn)=(Ar(n)-Ar(n1)*exp(-kr*Dt)-Ar(Dn))*(Ar(n)-Ar(n1)-Ar(Dn))*sirunc+(Ab(n)-Ab(n1)*exp(-kb*Dt)-Ab(Dn))*(Ab(n)-Ab(n1)-Ab(Dn))*sibunc;
    FBden(1,n-Dn)=(Ar(n)-Ar(n1)-Ar(Dn))^2*sirunc+(Ab(n)-Ab(n1)-Ab(Dn))^2*sibunc;
    FB(1,n-Dn)=FBnum(1,n-Dn)/FBden(1,n-Dn);
end

tauFB = Dt+0.5+0.00001 : 0.5 : Th;


% Campbell-Shiller

CS = zeros(Ttwo,Ttwo);

for n2 = 2 : 1 : Ttwo
    for n1 = 2 : 1 : n2-1
        
        n3=n2-n1+1;  
        tau1 = 0.5*(n1-1);
        tau2 = 0.5*(n2-1);
        tau3 = tau2-tau1;
        CSdepr = Ar(n3)/tau3*exp(-kr*tau1)-Ar(n2)/tau2;
        CSdepb = Ab(n3)/tau3*exp(-kb*tau1)-Ab(n2)/tau2;
        CSindr = tau1/tau3*(Ar(n2)/tau2-Ar(n1)/tau1);
        CSindb = tau1/tau3*(Ab(n2)/tau2-Ab(n1)/tau1);
        CS(n1,n2)=(CSdepr*CSindr*sirunc+CSdepb*CSindb*sibunc)/(CSindr^2*sirunc+CSindb^2*sibunc); 

    end
end

tauCS3 = 1.5+0.00001 : 0.5 : Th;


% Volatility of yields

Vol = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;


% Volatility of monthly yield changes

DVol = 100*(24*(sirunc*(1-exp(-kr/12))*Ar.^2+sibunc*(1-exp(-kb/12))*Ab.^2)).^0.5./tau;


% Volatility of annual yield changes

DVola = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;


% Correlation matrix

Correl = 100^2*(sirunc*(Ar./tau).'*(Ar./tau)+sibunc*(Ab./tau).'*(Ab./tau))./(Vol.'*Vol);


% Correlation matrix of monthly yield changes 

DCorrel = 100^2*24*(sirunc*(1-exp(-kr/12))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb/12))*(Ab./tau).'*(Ab./tau))./(DVol.'*DVol);


% Correlation matrix of annual yield changes 

DCorrela = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVola.'*DVola);


% Volume

Volume = (aal^2*exp(-dal*tau).^2.*Ar.^2*sir+(aal*exp(-dal*tau).*Ab-ath*(exp(-dal*tau)-exp(-dth*tau))).^2*sib).^0.5;


% One-off supply shocks

DIrr = cAr1^2*(Fint(kth,la1,dal)-Hint(la1,la1+dal,kth+dal)/(kth-la1))/la1 + cAr2^2*(Fint(kth,la2,dal)-Hint(la2,la2+dal,kth+dal)/(kth-la2))/la2 + cAr1*cAr2*((Fint(kth,la2,dal)-Hint(la2,la1+dal,kth+dal)/(kth-la1))/la1+(Fint(kth,la1,dal)-Hint(la1,la2+dal,kth+dal)/(kth-la2))/la2);
DIbb = cAb1^2*(Fint(kth,la1,dal)-Hint(la1,la1+dal,kth+dal)/(kth-la1))/la1 + cAb2^2*(Fint(kth,la2,dal)-Hint(la2,la2+dal,kth+dal)/(kth-la2))/la2 + cAb1*cAb2*((Fint(kth,la2,dal)-Hint(la2,la1+dal,kth+dal)/(kth-la1))/la1+(Fint(kth,la1,dal)-Hint(la1,la2+dal,kth+dal)/(kth-la2))/la2);
DIrb = cAr1*cAb1*(Fint(kth,la1,dal)-Hint(la1,la1+dal,kth+dal)/(kth-la1))/la1 + cAr2*cAb2*(Fint(kth,la2,dal)-Hint(la2,la2+dal,kth+dal)/(kth-la2))/la2 + cAr1*cAb2*(Fint(kth,la2,dal)-Hint(la2,la1+dal,kth+dal)/(kth-la1))/la1 + cAr2*cAb1*(Fint(kth,la1,dal)-Hint(la1,la2+dal,kth+dal)/(kth-la2))/la2;
DIbr = cAr1*cAb1*(Fint(kth,la1,dal)-Hint(la1,la1+dal,kth+dal)/(kth-la1))/la1 + cAr2*cAb2*(Fint(kth,la2,dal)-Hint(la2,la2+dal,kth+dal)/(kth-la2))/la2 + cAr2*cAb1*(Fint(kth,la2,dal)-Hint(la2,la1+dal,kth+dal)/(kth-la1))/la1 + cAr1*cAb2*(Fint(kth,la1,dal)-Hint(la1,la2+dal,kth+dal)/(kth-la2))/la2;

DI = (1+aal*sir*DIrr)*(1+aal*sib*DIbb)-aal^2*sir*sib*DIrb*DIbr;

Lar = DS*a*(sir*Ar*(1+aal*sib*DIbb)-sib*Ab*aal*sir*DIbr)/DI;
Lab = DS*a*(sib*Ab*(1+aal*sir*DIrr)-sir*Ar*aal*sib*DIrb)/DI;

Arint = (cAr1*((1-exp(-kth*tau))/kth-(exp(-la1*tau)-exp(-kth*tau))/(kth-la1))/la1 + cAr2*((1-exp(-kth*tau))/kth-(exp(-la2*tau)-exp(-kth*tau))/(kth-la2))/la2)./tau; 
Abint = (cAb1*((1-exp(-kth*tau))/kth-(exp(-la1*tau)-exp(-kth*tau))/(kth-la1))/la1 + cAb2*((1-exp(-kth*tau))/kth-(exp(-la2*tau)-exp(-kth*tau))/(kth-la2))/la2)./tau;

Supplyeffect = 100*(Lar'*Arint+Lab'*Abint);


% One-off forward guidance
 
chir = kr*(1+aal*sib*DIbb)/DI;
chib = -kr*aal*sib*DIrb/DI;
 
Arfint = (cAr1*((1-exp(-krb*tau))/krb-(exp(-la1*tau)-exp(-krb*tau))/(krb-la1))/la1 + cAr2*((1-exp(-krb*tau))/krb-(exp(-la2*tau)-exp(-krb*tau))/(krb-la2))/la2)./tau; 
Abfint = (cAb1*((1-exp(-krb*tau))/krb-(exp(-la1*tau)-exp(-krb*tau))/(krb-la1))/la1 + cAb2*((1-exp(-krb*tau))/krb-(exp(-la2*tau)-exp(-krb*tau))/(krb-la2))/la2)./tau;
 
ArfintEH = ((1-exp(-krb*tau))/krb-(exp(-kr*tau)-exp(-krb*tau))/(krb-kr))./tau;
 
Forwardguidance = 100*Drbar*(chir*Arfint+chib*Abfint);
ForwardguidanceEH = 100*Drbar*ArfintEH;


% Principal components

CovMR = sir*Ar(3:61)'*Ar(3:61) + sib*Ab(3:61)'*Ab(3:61);
CorrMR = CovMR./(((sir*Ar(3:61).^2+sib*Ab(3:61).^2).^0.5)'*(sir*Ar(3:61).^2+sib*Ab(3:61).^2).^0.5);

[pcR,latentR,explainedR] = pcacov(CovMR);

scaledpc1R = pcR(:,1)./(tau(3:61)')/pcR(1,1);

disp(['explainedR(1)     = ',num2str(explainedR(1))]);    
disp(['explainedR(2)     = ',num2str(explainedR(2))]);

CovMDy = sirunc*(1-exp(-kr/12))*(Ar(3:61)./tau(3:61)).'*(Ar(3:61)./tau(3:61))+sibunc*(1-exp(-kb/12))*(Ab(3:61)./tau(3:61)).'*(Ab(3:61)./tau(3:61));

[pcDy,latentDy,explainedDy] = pcacov(CovMDy);

scaledpc1Dy = pcDy(:,1)'/pcDy(1,1);

disp(['explainedDy(1)     = ',num2str(explainedDy(1))]);    
disp(['explainedDy(2)     = ',num2str(explainedDy(2))]); 


% Correlation with SDF (R1's question)

intth0Ar = cAr1*Hint(la1,dal,dth)+cAr2*Hint(la2,dal,dth);
intth0Ab = cAb1*Hint(la1,dal,dth)+cAb2*Hint(la2,dal,dth);

intintArAr = cAr1^2*Lint(la1,la1,dal)+cAr1*cAr2*(Lint(la1,la2,dal)+Lint(la2,la1,dal))+cAr2^2*Lint(la2,la2,dal);
intintArAb = cAr1*cAb1*Lint(la1,la1,dal)+cAr1*cAb2*Lint(la1,la2,dal)+cAr2*cAb1*Lint(la2,la1,dal)+cAr2*cAb2*Lint(la2,la2,dal);
intintAbAr = cAr1*cAb1*Lint(la1,la1,dal)+cAr1*cAb2*Lint(la2,la1,dal)+cAr2*cAb1*Lint(la1,la2,dal)+cAr2*cAb2*Lint(la2,la2,dal);
intintAbAb = cAb1^2*Lint(la1,la1,dal)+cAb1*cAb2*(Lint(la1,la2,dal)+Lint(la2,la1,dal))+cAb2^2*Lint(la2,la2,dal);

intintAr2Ar = cAr1*(cAr1^2*Kint(la1,la1,la1,dal)+cAr2^2*Kint(la2,la2,la1,dal)+2*cAr1*cAr2*Kint(la1,la2,la1,dal))+cAr2*(cAr1^2*Kint(la1,la1,la2,dal)+cAr2^2*Kint(la2,la2,la2,dal)+2*cAr1*cAr2*Kint(la1,la2,la2,dal));
intintAr2Ab = cAb1*(cAr1^2*Kint(la1,la1,la1,dal)+cAr2^2*Kint(la2,la2,la1,dal)+2*cAr1*cAr2*Kint(la1,la2,la1,dal))+cAb2*(cAr1^2*Kint(la1,la1,la2,dal)+cAr2^2*Kint(la2,la2,la2,dal)+2*cAr1*cAr2*Kint(la1,la2,la2,dal));
intintAb2Ar = cAr1*(cAb1^2*Kint(la1,la1,la1,dal)+cAb2^2*Kint(la2,la2,la1,dal)+2*cAb1*cAb2*Kint(la1,la2,la1,dal))+cAr2*(cAb1^2*Kint(la1,la1,la2,dal)+cAb2^2*Kint(la2,la2,la2,dal)+2*cAb1*cAb2*Kint(la1,la2,la2,dal));
intintAb2Ab = cAb1*(cAb1^2*Kint(la1,la1,la1,dal)+cAb2^2*Kint(la2,la2,la1,dal)+2*cAb1*cAb2*Kint(la1,la2,la1,dal))+cAb2*(cAb1^2*Kint(la1,la1,la2,dal)+cAb2^2*Kint(la2,la2,la2,dal)+2*cAb1*cAb2*Kint(la1,la2,la2,dal));

Convr = 0.5*(sir*intintAr2Ar+sib*intintAb2Ar);
Convb = 0.5*(sir*intintAr2Ab+sib*intintAb2Ab);

chir = ((kr*rbar+sir*(ath0*intth0Ar+aal*Convr))*(1+aal*sib*intintAbAb)-sib*(ath0*intth0Ab+aal*Convb)*aal*sir*intintAbAr)/((1+aal*sir*intintArAr)*(1+aal*sib*intintAbAb)-aal^2*sir*sib*intintArAb*intintAbAr);
chib = (sib*(ath0*intth0Ab+aal*Convb)*(1+aal*sir*intintArAr)-(kr*rbar+sir*(ath0*intth0Ar+aal*Convr))*aal*sib*intintArAb)/((1+aal*sir*intintArAr)*(1+aal*sib*intintAbAb)-aal^2*sir*sib*intintArAb*intintAbAr);

intAr2 = cAr1^2*Fint(la1,la1,dal)+cAr2^2*Fint(la2,la2,dal)+2*cAr1*cAr2*Fint(la1,la2,dal);
intArAb = cAr1*cAb1*Fint(la1,la1,dal)+cAr2*cAb2*Fint(la2,la2,dal)+(cAr1*cAb2+cAr2*cAb1)*Fint(la1,la2,dal);

intCAr = chir*intintArAr+chib*intintAbAr-Convr;
intCAb = chir*intintArAb+chib*intintAbAb-Convb;

SDFr = ath0*intth0Ar-aal*(intAr2*rbar+intCAr);
SDFb = ath0*intth0Ab-aal*(intArAb*rbar+intCAb);

UncER = sir*Ar*SDFr+sib*Ab*SDFb;
CorrRSDF = (sir*Ar*SDFr+sib*Ab*SDFb)./(sir*Ar.^2+sib*Ab.^2).^0.5/(sir*SDFr^2+sib*SDFb^2)^0.5;
UncSR = (sir*Ar*SDFr+sib*Ab*SDFb)./(sir*Ar.^2+sib*Ab.^2).^0.5;

Cr = chir*(cAr1*(tau-(1-exp(-la1*tau))/la1)/la1+cAr2*(tau-(1-exp(-la2*tau))/la2)/la2);
Cb = chib*(cAb1*(tau-(1-exp(-la1*tau))/la1)/la1+cAb2*(tau-(1-exp(-la2*tau))/la2)/la2);
Crr = 0.5*sir*(cAr1^2*(tau-2*(1-exp(-la1*tau))/la1+(1-exp(-2*la1*tau))/(2*la1))/la1^2+cAr2^2*(tau-2*(1-exp(-la2*tau))/la2+(1-exp(-2*la2*tau))/(2*la2))/la2^2+2*cAr1*cAr2*(tau-(1-exp(-la1*tau))/la1-(1-exp(-la2*tau))/la2+(1-exp(-(la1+la2)*tau))/(la1+la2))/(la1*la2));
Cbb = 0.5*sib*(cAb1^2*(tau-2*(1-exp(-la1*tau))/la1+(1-exp(-2*la1*tau))/(2*la1))/la1^2+cAb2^2*(tau-2*(1-exp(-la2*tau))/la2+(1-exp(-2*la2*tau))/(2*la2))/la2^2+2*cAb1*cAb2*(tau-(1-exp(-la1*tau))/la1-(1-exp(-la2*tau))/la2+(1-exp(-(la1+la2)*tau))/(la1+la2))/(la1*la2));

C = Cr+Cb-Crr-Cbb;
AvgYield = (Ar*rbar+C)./tau;


% Segmentation equilibrium

% yseg = (ath/aal)*(ones(1,61)-exp(-(dth-dal)*tau))./tau;


nFBCS = 2 : 1 : T;
nVol = 1 : 1 : T;

% Empirical values

% % Nov 1985 - Jan 2020
% % Annual FB coefficients from 2 to 30 years
% FBemp = [ 0.234	0.410	0.574	0.719	0.847	0.964	1.071	1.170	1.264	1.353	1.437	1.516	1.589	1.656	1.717	1.772	1.822	1.868	1.911	1.954	1.999	2.047	2.103	2.167	2.241	2.326	2.425	2.535	2.656 ];
% % Annual CS coefficients from 2 to 30 years
% CSemp = [ 0.527	0.197	-0.106	-0.366	-0.590	-0.781	-0.946	-1.087	-1.207	-1.308	-1.393	-1.463  -1.520	-1.564  -1.597  -1.621  -1.636  -1.645 	-1.647  -1.646  -1.643  -1.640  -1.638  -1.639  -1.646  -1.660  -1.684  -1.718  -1.764 ];
% % Unconditional volatility of yields from 1 to 30 years
% Volemp = [ 2.618  2.605  2.546  2.481  2.420  2.367  2.322  2.284  2.252  2.226  2.203  2.184  2.167  2.153  2.139  2.127  2.115  2.105  2.094  2.084  2.075  2.066  2.057  2.048  2.040  2.032  2.025  2.017 2.011  2.004 ];
% % Unconditional volatility of monthly yield changes from 1 to 30 years
% DVolemp = [ 0.830	0.936	0.982	0.998	0.998	0.992	0.983	0.974	0.965	0.957	0.950	0.943	0.936	0.928	0.921	0.914	0.906	0.898	0.890	0.883	0.877	0.871	0.867	0.864	0.863	0.865	0.869	0.876	0.886	0.899 ];
% % Unconditional volatility of annual yield changes from 1 to 30 years
% DVolempa = [ 1.265	1.163	1.075	1.005	0.951	0.910	0.878	0.852	0.831	0.813	0.797	0.783	0.769	0.757	0.745	0.734	0.724	0.714	0.705	0.696	0.688	0.682	0.676	0.671	0.668	0.666	0.665	0.666	0.668	0.672 ];
% % Unconditional correlations for one-year bond
% Correlemp = [ 1.000	0.995	0.986	0.974	0.961	0.949	0.936	0.924	0.913	0.903	0.894	0.886	0.879	0.873	0.868	0.864	0.861	0.858	0.855	0.853	0.851	0.849	0.848	0.847	0.845	0.844	0.843	0.841	0.840	0.838 ];
% % Unconditional correlations of monthly yield changes for one-year bond
% DCorrelemp = [ 1.000	0.952	0.894	0.846	0.804	0.765	0.729	0.695	0.664	0.635	0.609	0.587	0.567	0.551	0.538	0.528	0.520	0.514	0.511	0.509	0.509	0.509	0.510	0.511	0.511	0.512	0.511	0.509	0.507	0.503 ];
% % Unconditional correlations of annual yield changes for one-year bond
% DCorrelempa = [ 1.000	0.974	0.926	0.872	0.814	0.755	0.699	0.647	0.599	0.556	0.518	0.485	0.456	0.432	0.410	0.393	0.377	0.365	0.354	0.345	0.337	0.331	0.325	0.321	0.316	0.312	0.308	0.305	0.301	0.297 ];
% % Fraction of annual yield changes explained by first principal component
% explainedDyemp(1) = 81.3822;
% % First principal component of annual yield changes
% scaledpc1Dyemp = [ 1.0000    1.0970    1.1199    1.1179    1.1053    1.0870    1.0652    1.0415    1.0169    0.9920    0.9676    0.9439   0.9213    0.8998    0.8798    0.8610    0.8436    0.8275    0.8126    0.7988    0.7861    0.7744    0.7636    0.753     0.7444    0.7359    0.7280    0.7206    0.7138   0.7074 ];

% Jan 1999 - Jan 2020
% Annual FB coefficients from 2 to 30 years
FBemp = [ -0.040 0.210 	0.432	0.630	0.804	0.955	1.087	1.204	1.310	1.409	1.503	1.595	1.689	1.786	1.888	1.995	2.106	2.222	2.340	2.460	2.580   2.700   2.812	2.921   3.030	3.132	3.232   3.328   3.422 ];
% Annual CS coefficients from 2 to 30 years
CSemp = [ 1.056   0.578    0.176  -0.169  -0.464  -0.714  -0.923  -1.096  -1.237  -1.352	-1.447  -1.523  -1.587  -1.639  -1.684  -1.723  -1.759  -1.792  -1.826	-1.859  -1.895  -1.934  -1.977  -2.024  -2.076  -2.135  -2.200  -2.273  -2.352 ];
% Unconditional volatility of yields from 1 to 30 years
Volemp = [ 1.886  1.803  1.700  1.607  1.532  1.475  1.434  1.406  1.386  1.373  1.363  1.355  1.348  1.340  1.333  1.324  1.314  1.303  1.291  1.278  1.264  1.248  1.232  1.216  1.198  1.180  1.162  1.144  1.125  1.107 ];
% Unconditional volatility of monthly yield changes from 1 to 30 years
DVolemp = [ 0.687	0.796	0.859	0.890	0.905	0.911	0.913	0.913	0.911	0.907	0.901	0.894	0.886	0.876	0.866	0.856	0.845	0.835	0.825	0.816	0.807	0.799	0.792	0.786	0.781	0.778	0.776	0.776	0.777	0.780 ];
% Unconditional volatility of annual yield changes from 1 to 30 years
DVolempa = [ 1.240	1.098	0.985	0.902	0.841	0.796	0.762	0.736	0.714	0.695	0.678	0.663	0.650	0.638	0.627	0.618	0.611	0.605	0.601	0.598	0.596	0.596	0.597	0.600	0.603	0.608	0.613	0.619	0.626	0.634 ];
% Unconditional correlations for one-year bond
Correlemp = [ 1.000	0.992	0.975	0.952	0.925	0.895	0.864  0.833	0.803	0.776	0.751	0.730	0.711	0.694	0.680	0.668  0.658	0.650	0.642	0.636	0.631	0.626	0.622	0.618	0.615  0.612	0.610	0.607	0.605	0.602 ];
% Unconditional correlations of monthly yield changes for one-year bond
DCorrelemp = [ 1.000	0.923	0.837	0.769	0.713	0.663	0.619	0.580	0.545	0.514	0.488	0.465	0.447	0.431	0.418	0.407	0.399	0.392	0.387	0.384	0.381	0.380	0.379	0.379	0.379	0.380	0.381	0.381	0.382	0.382 ];
% Unconditional correlations of annual yield changes for one-year bond
DCorrelempa = [ 1.000	0.973	0.919	0.851	0.777	0.701	0.626	0.556	0.493	0.436	0.385	0.341	0.303	0.270	0.241	0.217	0.196	0.179	0.165	0.153	0.144	0.137	0.131	0.128	0.125	0.124	0.124	0.124	0.125	0.127 ];
% Fraction of annual yield changes explained by first principal component
explainedDyemp(1) = 73.7689;
% First principal component of annual yield changes
scaledpc1Dyemp = [   1.0000    1.0814    1.1141    1.1271    1.1272    1.1167    1.0980    1.0734    1.0451    1.0148    0.9843    0.9546   0.9264    0.9004    0.8768    0.8558    0.8374    0.8217    0.8084    0.7974    0.7886    0.7817    0.7767    0.7732  0.7712    0.7704    0.7708    0.7722    0.7744   0.7773 ];

% Figures

figure(1);
h=plot(tau,Ar,'r-',tau,Ab,'r--');
set(h,'LineWidth',2.5);
xlim([0 T]);
legend('r','beta');
xlabel('Maturity (years)');

figure(2);
h=plot(tau,Arb,'r-',tau,Abb,'r--');
set(h,'LineWidth',2.5);
xlim([0 T]);
legend('r','beta');
xlabel('Maturity (years)');

figure(3);
h=plot(tauFB,FB,'r-',nFBCS,FBemp,'k+');
set(h,'LineWidth',2.5);
axis([0 T 0 3.5]);
xlabel('Maturity (years)'); 
ylabel('Fama-Bliss regression coefficient'); 
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'FBnom99.eps','bounds','tight','Color','rgb');

figure(4);
h=plot(tauCS3,CS(3,4:Ttwo),'r-',nFBCS,CSemp,'k+');
set(h,'LineWidth',2.5);
axis([0 T -2.5 1]);
xlabel('Maturity (years)'); 
ylabel('Campbell-Shiller regression coefficient'); 
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'CSnom99.eps','bounds','tight','Color','rgb');

figure(5);
h=plot(tau(3:61),Vol(3:61),'r-',nVol,Volemp,'k+');
set(h,'LineWidth',2.5);
axis([0 T 0 3]);
xlabel('Maturity (years)'); 
ylabel('Volatility of yield -- Levels'); 
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'Volnom99.eps','bounds','tight','Color','rgb');

figure(6);
h=plot(tau(3:61),DVola(3:61),'r-',nVol,DVolempa,'k+');
set(h,'LineWidth',2.5);
axis([0 T 0 1.5]);
xlabel('Maturity (years)'); 
ylabel('Volatility of yield -- Annual changes'); 
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'DVolanom99.eps','bounds','tight','Color','rgb');

figure(7);
h=plot(tau(3:61),DCorrela(3,3:61),'r-',nVol,DCorrelempa,'k+');
set(h,'LineWidth',2.5);
axis([0 T 0 1]);
xlabel('Maturity (years)'); 
ylabel('Correlation with one-year yield -- Annual changes'); 
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'DCorrelanom99.eps','bounds','tight','Color','rgb');

figure(8);
h=plot(tau(3:61),scaledpc1Dy,'r-',nVol,scaledpc1Dyemp,'k+');
set(h,'LineWidth',2.5);
axis([0 T 0 1.5]);
xlabel('Maturity (years)'); 
ylabel('First principal component -- Annual yield changes'); 
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'PCnom99.eps','bounds','tight','Color','rgb');

figure(9);
h=plot(Volume(3:61),'r-');
set(h,'LineWidth',2.5);
axis([0 T 0 3]);
xlabel('Maturity (years)'); 
ylabel('Volume'); 
ax = gca;
ax.FontSize = 12;

QEweights = [0 0 0.0644 0 0 0 0.2587 0 0 0 0.2466 0 0 0 0.2409 0 0 0 0.0440 0 0 0 0.0450 0 0 0 0.0298 0 0 0 0.0092 0 0 0 0.0196 0 0 0 0.0185 0 0 0 0.0074 0 0 0 0 0 0 0 0 0 0 0 0.0020 0 0 0 0.0140 0 0];

QESupplyeffect = QEweights*Supplyeffect;

QEweightsCF15 = [0 0 0 0 0 0 0 0 0 0 0.2939 0 0 0 0.2409 0 0 0 0.1742 0 0 0 0.0450 0 0 0 0.0445 0 0 0 0.0243 0 0 0 0.0307 0 0 0 0.0355 0 0 0 0.0235 0 0 0 0 0 0 0 0 0 0 0 0.0339 0 0 0 0.0535 0 0];

QESupplyeffectCF15 = QEweightsCF15*Supplyeffect;

figure(10);
h=plot(tau,Supplyeffect(5,:),'r',tau,Supplyeffect(11,:),'g',tau,Supplyeffect(21,:),'c',tau,Supplyeffect(41,:),'b',tau,Supplyeffect(61,:),'k',tau,QESupplyeffect,'k--');
set(h,'LineWidth',2.5);
xlim([0 T]);
ylim([-2.6,0.1]);
% ylim([-4.5,0.3]); % For 1999-2020 sample
xlabel('Maturity (years)'); 
ylabel('Yield change'); 
legend('2-yr','5-yr','10-yr','20-yr','30-yr','QE mix');
legend('Location','southwest');
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'QEnommain01.eps','bounds','tight','Color','rgb');

figure(11);
h=plot(tau,Forwardguidance,'r-',tau,ForwardguidanceEH,'r--');
set(h,'LineWidth',2.5);
xlim([0 T]);
ylim([-2.1,0.6]);
% ylim([-2.1,0.8]); % For 1999-2020 sample
xlabel('Maturity (years)'); 
ylabel('Yield change'); 
% tix=get(gca,'ytick')';
% set(gca,'yticklabel',num2str(tix,'%.3f'))
legend('Forward guidance','Forward guidance EH');
legend('Location','northwest');
ax = gca;
ax.FontSize = 12;

% exportfig(gcf,'ForwGuidnom9902.eps','bounds','tight','Color','rgb');

