% Computes sensitivity matrix

function F = SensMatrix(kb,aal,ath,dal,dth)


global kr sir sib T;


epsilon = 0.001;

epsilonkr = kr*epsilon; 
epsilonsir = sir*epsilon;
epsilonkb = kb*epsilon;
epsilonath = ath*epsilon;
epsilonaal = aal*epsilon;
epsilondal = dal*epsilon;
epsilondth = dth*epsilon;


% Initial condition for M

% % Initial condition, method 1 (sib=0)
% 
% options=optimset('MaxFunEvals',100000,'MaxIter',10000);
% 
% Hkr1 = @(x) x-kr-aal*sir*Fint(x,x,dal);
% hkr = fzero(Hkr1,kr,options);
% 
% x01 = Fint(hkr,hkr,dal);
% 
% % zb is coefficient of bt when sib=0 and kb=0
% 
% zb = ath*sir*Hint(hkr,dal,dth)/(1+aal*sir*(Gint(hkr,dal)-Fint(hkr,hkr,dal))/hkr);
% 
% % Itau2 = int_0^T tau^2*exp(-dalx*tau)*dtau
% 
% Itau2 = 2/dal^3*(1-exp(-dal*T)-dal*T*exp(-dal*T)-dal^2*T^2/2*exp(-dal*T));
% 
% x02 = (zb/hkr)^2*(Itau2 - 2*Gint(hkr,dal) + Fint(hkr,hkr,dal));
% 
% x03 = zb/hkr*(Gint(hkr,dal)-Fint(hkr,hkr,dal));
% 
% x04 = Hint(hkr,dal,dth);
% 
% % DItau1 = int_0^T tau*(exp(-dal*tau)-exp(-dth*tau))*dtau
% 
% DItau1 = 1/dal^2*(1-exp(-dal*T)-dal*T*exp(-dal*T))-1/dth^2*(1-exp(-dth*T)-dth*T*exp(-dth*T));
% 
% x05 = zb/hkr*(DItau1 - Hint(hkr,dal,dth));
% 
% M011 = kr+aal*sir*x01;
% 
% M012 = aal*sib*x03 ;
% 
% M021 = -sir*(ath*x04-aal*x03);
% 
% M022 = kb-sib*(ath*x05-aal*x02);

% Initial condition, method 2 (aal=0)

options=optimset('MaxFunEvals',100000,'MaxIter',10000,'Display','off');

Hkbloc = @(x)Hkb(x,kb,aal,ath,dal,dth);
                      
[hkb,fval,exitflag] = fsolve(Hkbloc,kb,options);

ZAb = sir*ath*Hint(kr,dal,dth)/(1+sir*aal*(Fint(kr,kr,dal)-Fint(kr,hkb,dal))/(hkb-kr));

M011 = kr+sir*aal*Fint(kr,kr,dal);

M012 = sib*aal*ZAb*(Fint(kr,kr,dal)-Fint(kr,hkb,dal))/(hkb-kr);

M021 = -sir*(ath*Hint(kr,dal,dth)-aal*ZAb*(Fint(kr,kr,dal)-Fint(kr,hkb,dal))/(hkb-kr));

M022 = kb-sib*ZAb*(ath*(Hint(kr,dal,dth)-Hint(hkb,dal,dth))-aal*ZAb*(Fint(kr,kr,dal)+Fint(hkb,hkb,dal)-2*Fint(kr,hkb,dal))/(hkb-kr))/(hkb-kr);      

M0 = [ M011 M012 M021 M022 ];


% Baseline solution 

MmatlocSSR = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSR,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Vol = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVola = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrela = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVola.'*DVola);

Vol1 = Vol(3);

DVola1 = DVola(3);

Volmean = mean(Vol(3:61));

DVolamean = mean(DVola(3:61));

DCorrelamean = mean(DCorrela(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2 = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30 = sum(Volume(112:Tten))/VolumeTotal;


% Sensitivities with respect to kr

% High kr

kr = kr + epsilonkr;

MmatlocSSRkrh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRkrh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volkrh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolakrh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelakrh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolakrh.'*DVolakrh);

Vol1krh = Volkrh(3);

DVola1krh = DVolakrh(3);

Volmeankrh = mean(Volkrh(3:61));

DVolameankrh = mean(DVolakrh(3:61));

DCorrelameankrh = mean(DCorrelakrh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2krh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30krh = sum(Volume(112:Tten))/VolumeTotal;

% Low kr

kr = kr - 2*epsilonkr;

MmatlocSSRkrl = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRkrl,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volkrl = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolakrl = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelakrl = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolakrl.'*DVolakrl);

Vol1krl = Volkrl(3);

DVola1krl = DVolakrl(3);

Volmeankrl = mean(Volkrl(3:61));

DVolameankrl = mean(DVolakrl(3:61));

DCorrelameankrl = mean(DCorrelakrl(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2krl = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30krl = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,1) = (Vol1krh - Vol1krl)/2/Vol1;
SM(2,1) = (DVola1krh - DVola1krl)/2/DVola1;
SM(3,1) = (Volmeankrh - Volmeankrl)/2/Volmean;
SM(4,1) = (DVolameankrh - DVolameankrl)/2/DVolamean;
SM(5,1) = (DCorrelameankrh - DCorrelameankrl)/2/DCorrelamean;
SM(6,1) = (VolumeBelow2krh - VolumeBelow2krl)/2/VolumeBelow2;
SM(7,1) = (VolumeBetween11and30krh - VolumeBetween11and30krl)/2/VolumeBetween11and30;

kr = kr + epsilonkr;


% Sensitivities with respect to sir

% High sir

sir = sir + epsilonsir;

MmatlocSSRsirh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRsirh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volsirh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolasirh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelasirh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolasirh.'*DVolasirh);

Vol1sirh = Volsirh(3);

DVola1sirh = DVolasirh(3);

Volmeansirh = mean(Volsirh(3:61));

DVolameansirh = mean(DVolasirh(3:61));

DCorrelameansirh = mean(DCorrelasirh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2sirh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30sirh = sum(Volume(112:Tten))/VolumeTotal;

% Low sir

sir = sir - 2*epsilonsir;

MmatlocSSRsirl = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRsirl,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volsirl = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolasirl = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelasirl = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolasirl.'*DVolasirl);

Vol1sirl = Volsirl(3);

DVola1sirl = DVolasirl(3);

Volmeansirl = mean(Volsirl(3:61));

DVolameansirl = mean(DVolasirl(3:61));

DCorrelameansirl = mean(DCorrelasirl(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2sirl = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30sirl = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,2) = (Vol1sirh - Vol1sirl)/2/Vol1;
SM(2,2) = (DVola1sirh - DVola1sirl)/2/DVola1;
SM(3,2) = (Volmeansirh - Volmeansirl)/2/Volmean;
SM(4,2) = (DVolameansirh - DVolameansirl)/2/DVolamean;
SM(5,2) = (DCorrelameansirh - DCorrelameansirl)/2/DCorrelamean;
SM(6,2) = (VolumeBelow2sirh - VolumeBelow2sirl)/2/VolumeBelow2;
SM(7,2) = (VolumeBetween11and30sirh - VolumeBetween11and30sirl)/2/VolumeBetween11and30;

sir = sir + epsilonsir;


% Sensitivities with respect to kb

% High kb

kb = kb + epsilonkb;

MmatlocSSRkbh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRkbh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volkbh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolakbh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelakbh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolakbh.'*DVolakbh);

Vol1kbh = Volkbh(3);

DVola1kbh = DVolakbh(3);

Volmeankbh = mean(Volkbh(3:61));

DVolameankbh = mean(DVolakbh(3:61));

DCorrelameankbh = mean(DCorrelakbh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2kbh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30kbh = sum(Volume(112:Tten))/VolumeTotal;

% Low kb

kb = kb - 2*epsilonkb;

MmatlocSSRkbl = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRkbl,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volkbl = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolakbl = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelakbl = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolakbl.'*DVolakbl);

Vol1kbl = Volkbl(3);

DVola1kbl = DVolakbl(3);

Volmeankbl = mean(Volkbl(3:61));

DVolameankbl = mean(DVolakbl(3:61));

DCorrelameankbl = mean(DCorrelakbl(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2kbl = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30kbl = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,3) = (Vol1kbh - Vol1kbl)/2/Vol1;
SM(2,3) = (DVola1kbh - DVola1kbl)/2/DVola1;
SM(3,3) = (Volmeankbh - Volmeankbl)/2/Volmean;
SM(4,3) = (DVolameankbh - DVolameankbl)/2/DVolamean;
SM(5,3) = (DCorrelameankbh - DCorrelameankbl)/2/DCorrelamean;
SM(6,3) = (VolumeBelow2kbh - VolumeBelow2kbl)/2/VolumeBelow2;
SM(7,3) = (VolumeBetween11and30kbh - VolumeBetween11and30kbl)/2/VolumeBetween11and30;

kb = kb + epsilonkb;


% Sensitivities with respect to ath

% High ath

ath = ath + epsilonath;

MmatlocSSRathh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRathh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volathh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolaathh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelaathh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolaathh.'*DVolaathh);

Vol1athh = Volathh(3);

DVola1athh = DVolaathh(3);

Volmeanathh = mean(Volathh(3:61));

DVolameanathh = mean(DVolaathh(3:61));

DCorrelameanathh = mean(DCorrelaathh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2athh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30athh = sum(Volume(112:Tten))/VolumeTotal;

% Low ath

ath = ath - 2*epsilonath;

MmatlocSSRathl = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRathl,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volathl = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolaathl = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelaathl = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolaathl.'*DVolaathl);

Vol1athl = Volathl(3);

DVola1athl = DVolaathl(3);

Volmeanathl = mean(Volathl(3:61));

DVolameanathl = mean(DVolaathl(3:61));

DCorrelameanathl = mean(DCorrelaathl(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2athl = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30athl = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,4) = (Vol1athh - Vol1athl)/2/Vol1;
SM(2,4) = (DVola1athh - DVola1athl)/2/DVola1;
SM(3,4) = (Volmeanathh - Volmeanathl)/2/Volmean;
SM(4,4) = (DVolameanathh - DVolameanathl)/2/DVolamean;
SM(5,4) = (DCorrelameanathh - DCorrelameanathl)/2/DCorrelamean;
SM(6,4) = (VolumeBelow2athh - VolumeBelow2athl)/2/VolumeBelow2;
SM(7,4) = (VolumeBetween11and30athh - VolumeBetween11and30athl)/2/VolumeBetween11and30;

ath = ath + epsilonath;


% Sensitivities with respect to aal

% High aal

% aal0 = aal;
% ath0 = ath;
aal = aal + epsilonaal;
% ath = ath0*aal/aal0;

MmatlocSSRaalh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRaalh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volaalh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolaaalh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelaaalh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolaaalh.'*DVolaaalh);

Vol1aalh = Volaalh(3);

DVola1aalh = DVolaaalh(3);

Volmeanaalh = mean(Volaalh(3:61));

DVolameanaalh = mean(DVolaaalh(3:61));

DCorrelameanaalh = mean(DCorrelaaalh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2aalh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30aalh = sum(Volume(112:Tten))/VolumeTotal;

% Low aal

aal = aal - 2*epsilonaal;
% ath = ath0*aal/aal0;

MmatlocSSRaall = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRaall,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Volaall = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVolaaall = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorrelaaall = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVolaaall.'*DVolaaall);

Vol1aall = Volaall(3);

DVola1aall = DVolaaall(3);

Volmeanaall = mean(Volaall(3:61));

DVolameanaall = mean(DVolaaall(3:61));

DCorrelameanaall = mean(DCorrelaaall(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2aall = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30aall = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,5) = (Vol1aalh - Vol1aall)/2/Vol1;
SM(2,5) = (DVola1aalh - DVola1aall)/2/DVola1;
SM(3,5) = (Volmeanaalh - Volmeanaall)/2/Volmean;
SM(4,5) = (DVolameanaalh - DVolameanaall)/2/DVolamean;
SM(5,5) = (DCorrelameanaalh - DCorrelameanaall)/2/DCorrelamean;
SM(6,5) = (VolumeBelow2aalh - VolumeBelow2aall)/2/VolumeBelow2;
SM(7,5) = (VolumeBetween11and30aalh - VolumeBetween11and30aall)/2/VolumeBetween11and30;

aal = aal + epsilonaal;
% ath = ath0;


% Sensitivities with respect to dal

% High dal

% dal0 = dal;
% ath0 = ath;
dal = dal + epsilondal;
% ath = ath0*(dth-dal0)/(dth-dal);

MmatlocSSRdalh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRdalh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Voldalh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVoladalh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorreladalh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVoladalh.'*DVoladalh);

Vol1dalh = Voldalh(3);

DVola1dalh = DVoladalh(3);

Volmeandalh = mean(Voldalh(3:61));

DVolameandalh = mean(DVoladalh(3:61));

DCorrelameandalh = mean(DCorreladalh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2dalh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30dalh = sum(Volume(112:Tten))/VolumeTotal;

% Low dal

dal = dal - 2*epsilondal;
% ath = ath0*(dth-dal0)/(dth-dal);

MmatlocSSRdall = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRdall,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Voldall = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVoladall = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorreladall = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVoladall.'*DVoladall);

Vol1dall = Voldall(3);

DVola1dall = DVoladall(3);

Volmeandall = mean(Voldall(3:61));

DVolameandall = mean(DVoladall(3:61));

DCorrelameandall = mean(DCorreladall(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2dall = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30dall = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,6) = (Vol1dalh - Vol1dall)/2/Vol1;
SM(2,6) = (DVola1dalh - DVola1dall)/2/DVola1;
SM(3,6) = (Volmeandalh - Volmeandall)/2/Volmean;
SM(4,6) = (DVolameandalh - DVolameandall)/2/DVolamean;
SM(5,6) = (DCorrelameandalh - DCorrelameandall)/2/DCorrelamean;
SM(6,6) = (VolumeBelow2dalh - VolumeBelow2dall)/2/VolumeBelow2;
SM(7,6) = (VolumeBetween11and30dalh - VolumeBetween11and30dall)/2/VolumeBetween11and30;

dal = dal + epsilondal;
% ath = ath0;


% Sensitivities with respect to dth

% High dth

% dth0 = dth;
% ath0 = ath;
% dal0 = dal;
dth = dth + epsilondth;
% ath = ath0*(dth0-dal)/(dth-dal);
% dal = dal + epsilondth;

MmatlocSSRdthh = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRdthh,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Voldthh = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVoladthh = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorreladthh = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVoladthh.'*DVoladthh);

Vol1dthh = Voldthh(3);

DVola1dthh = DVoladthh(3);

Volmeandthh = mean(Voldthh(3:61));

DVolameandthh = mean(DVoladthh(3:61));

DCorrelameandthh = mean(DCorreladthh(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2dthh = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30dthh = sum(Volume(112:Tten))/VolumeTotal;

% Low dth

dth = dth - 2*epsilondth;
% ath = ath0*(dth0-dal)/(dth-dal);
% dal = dal - 2*epsilondth;

MmatlocSSRdthl = @(M)Mmat(M,kb,aal,ath,dal,dth);
                      
[M,fval,exitflag] = fsolve(MmatlocSSRdthl,M0,options);

disp(['exitflag     = ',num2str(exitflag)]);

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;

sirunc = sir/2/kr;
sibunc = sib/2/kb;

Voldthl = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;

DVoladthl = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kb))*Ab.^2)).^0.5./tau;

DCorreladthl = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kb))*(Ab./tau).'*(Ab./tau))./(DVoladthl.'*DVoladthl);

Vol1dthl = Voldthl(3);

DVola1dthl = DVoladthl(3);

Volmeandthl = mean(Voldthl(3:61));

DVolameandthl = mean(DVoladthl(3:61));

DCorrelameandthl = mean(DCorreladthl(3:61));

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aal^2*exp(-dal*tauVolume).^2.*ArVolume.^2*sir+(aal*exp(-dal*tauVolume).*AbVolume-ath*(exp(-dal*tauVolume)-exp(-dth*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2dthl = sum(Volume(1:21))/VolumeTotal;
VolumeBetween11and30dthl = sum(Volume(112:Tten))/VolumeTotal;

% SensMatrix

SM(1,7) = (Vol1dthh - Vol1dthl)/2/Vol1;
SM(2,7) = (DVola1dthh - DVola1dthl)/2/DVola1;
SM(3,7) = (Volmeandthh - Volmeandthl)/2/Volmean;
SM(4,7) = (DVolameandthh - DVolameandthl)/2/DVolamean;
SM(5,7) = (DCorrelameandthh - DCorrelameandthl)/2/DCorrelamean;
SM(6,7) = (VolumeBelow2dthh - VolumeBelow2dthl)/2/VolumeBelow2;
SM(7,7) = (VolumeBetween11and30dthh - VolumeBetween11and30dthl)/2/VolumeBetween11and30;

dth = dth - epsilondth;
% ath = ath0;
% dal = dal0;


% SM(:,2) = SM(:,2)-SM(:,1)*SM(1,2)/SM(1,1);

% SM(:,5) = SM(:,5)-SM(:,4)*SM(4,5)/SM(4,4);
% SM(:,6) = SM(:,6)-SM(:,4)*SM(4,6)/SM(4,4);
% SM(:,7) = SM(:,7)-SM(:,4)*SM(4,7)/SM(4,4);
% 
% SM(:,6) = SM(:,6)-SM(:,5)*SM(5,6)/SM(5,5);
% SM(:,7) = SM(:,7)-SM(:,5)*SM(5,7)/SM(5,5);

% SM(:,7) = SM(:,7)-SM(:,6)*SM(6,7)/SM(6,6);

% SM(:,4) = SM(:,4)-SM(:,3)*SM(3,4)/SM(3,3);


F = 1000*SM;




end

