%Computes fit for Volume

function F = FitVolume(dy,kby,aaly,athy)

global kr sir sib T;

% Empirical volume
% Monthly volume: Ratio tau<=2 years, 2<tau<=3 years, 3<tau<=6 years, 6<x<=7 years, 7<x<=11
% years, and 11<x years, to total volume
% Average Apr 2013 - Jan 2020, no T-bills
Volumeemp = [ 0.199	 0.132	0.292	0.080	0.204	0.094 ];
% % Average Apr 2013 - Jan 2020, with T-bills
% Volumeemp = [ 0.342	 0.108	0.240	0.065	0.167	0.077 ];

daly = dy(1);
% dthy = dy(2);
dthy = dy(1)+dy(2)^2+0.01;

% Solve for M

% % Initial condition, method 1 (sib=0)
% 
% options=optimset('MaxFunEvals',100000,'MaxIter',10000);
% 
% hkr = fzero(@Hkr,kr,options);
% 
%     function F = Hkr(x);
% 
% F = x-kr-aaly*sir*Fint(x,x,daly);
% 
%      end
% 
% x01 = Fint(hkr,hkr,daly);
% 
% % zb is coefficient of bt when sib=0 and kb=0
% 
% zb = athy*sir*Hint(hkr,daly,dthy)/(1+aaly*sir*(Gint(hkr,daly)-Fint(hkr,hkr,daly))/hkr);
% 
% % Itau2 = int_0^T tau^2*exp(-dalx*tau)*dtau
% 
% Itau2 = 2/daly^3*(1-exp(-daly*T)-daly*T*exp(-daly*T)-daly^2*T^2/2*exp(-daly*T));
% 
% x02 = (zb/hkr)^2*(Itau2 - 2*Gint(hkr,daly) + Fint(hkr,hkr,daly));
% 
% x03 = zb/hkr*(Gint(hkr,daly)-Fint(hkr,hkr,daly));
% 
% x04 = Hint(hkr,daly,dthy);
% 
% % DItau1 = int_0^T tau*(exp(-daly*tau)-exp(-dthy*tau))*dtau
% 
% DItau1 = 1/daly^2*(1-exp(-daly*T)-daly*T*exp(-daly*T))-1/dthy^2*(1-exp(-dthy*T)-dthy*T*exp(-dthy*T));
% 
% x05 = zb/hkr*(DItau1 - Hint(hkr,daly,dthy));
% 
% M011 = kr+aaly*sir*x01;
% 
% M012 = aaly*sib*x03 ;
% 
% M021 = -sir*(athy*x04-aaly*x03);
% 
% M022 = kby-sib*(athy*x05-aaly*x02);

% Initial condition, method 2 (aal=0)

options=optimset('MaxFunEvals',100000,'MaxIter',10000,'Display','off');

Hkbloc = @(x)Hkb(x,kby,aaly,athy,daly,dthy);
                      
[hkb,fval,exitflag] = fsolve(Hkbloc,kby,options);

ZAb = sir*athy*Hint(kr,daly,dthy)/(1+sir*aaly*(Fint(kr,kr,daly)-Fint(kr,hkb,daly))/(hkb-kr));

M011 = kr+sir*aaly*Fint(kr,kr,daly);

M012 = sib*aaly*ZAb*(Fint(kr,kr,daly)-Fint(kr,hkb,daly))/(hkb-kr);

M021 = -sir*(athy*Hint(kr,daly,dthy)-aaly*ZAb*(Fint(kr,kr,daly)-Fint(kr,hkb,daly))/(hkb-kr));

M022 = kby-sib*ZAb*(athy*(Hint(kr,daly,dthy)-Hint(hkb,daly,dthy))-aaly*ZAb*(Fint(kr,kr,daly)+Fint(hkb,hkb,daly)-2*Fint(kr,hkb,daly))/(hkb-kr))/(hkb-kr);      


% Solve non-linear system

M0 = [ M011 M012 M021 M022 ];

options=optimset('MaxFunEvals',100000,'MaxIter',10000,'Display','off');

MmatlocFitVolume = @(M)Mmat(M,kby,aaly,athy,daly,dthy);
                      
[M,fval,exitflag] = fsolve(MmatlocFitVolume,M0,options);


if exitflag < 1
    
    F = 1e6;
    
else

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

% Display

disp(['Eigenvalues     = ',num2str(eigvalues)]);
disp(['Eigenvector 1     = ',num2str(eigvector1)]);    
disp(['Eigenvector 2     = ',num2str(eigvector2)]); 

% Curves

% coefs in Ar

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

% coefs in Ab

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;


% Volume

ThVolume=T+0.1;
Tten = 10*T+1;
tauVolume = 0.00001 : 0.1 : ThVolume;

ArVolume = cAr1*(1-exp(-la1*tauVolume))/la1 + cAr2*(1-exp(-la2*tauVolume))/la2;
AbVolume = cAb1*(1-exp(-la1*tauVolume))/la1 + cAb2*(1-exp(-la2*tauVolume))/la2;

Volume = (aaly^2*exp(-daly*tauVolume).^2.*ArVolume.^2*sir+(aaly*exp(-daly*tauVolume).*AbVolume-athy*(exp(-daly*tauVolume)-exp(-dthy*tauVolume))).^2*sib).^0.5;
VolumeTotal = sum(Volume(1:Tten));
VolumeBelow2 = sum(Volume(1:21))/VolumeTotal;
VolumeBetween2and3 = sum(Volume(22:31))/VolumeTotal;
VolumeBetween11and30 = sum(Volume(112:Tten))/VolumeTotal;

FitVolume(1) = (VolumeBelow2-Volumeemp(1))^2;
% FitVolume(1) = (VolumeBelow2+VolumeBetween2and3-Volumeemp(1)-Volumeemp(2))^2;
FitVolume(6) = (VolumeBetween11and30-Volumeemp(6))^2;

Volumeinel = athy*(exp(-daly*tauVolume)-exp(-dthy*tauVolume))*sib^0.5;
Volumeel = aaly*exp(-daly*tauVolume).*(ArVolume.^2*sir+AbVolume.^2*sib).^0.5;
VolumeRat = Volumeel./Volumeinel;

disp(['Volume     = ',num2str(Volume)]);
disp(['VolumeRat     = ',num2str(VolumeRat)]);

disp(['DVolume(1)     = ',num2str(VolumeBelow2-Volumeemp(1))]);
disp(['DVolume(2)     = ',num2str(VolumeBetween11and30-Volumeemp(6))]);

F = FitVolume(1)+FitVolume(6);

end

end
