% Computes fit as measured by FB and CS coefficients and by volatility and correlation levels and changes

function F = SSRReal(kbx,aalx,athx,dalx,dthx)


global kr sir sib T;


% Empirical values

% Jan 1999 - Jan 2020
% Annual FB coefficients from 2 to 20 years. Fill one-year yield with spline
FBemp = [ 0.517  0.709  0.868  0.977  1.047  1.091  1.122  1.152  1.189  1.236  1.297  1.371  1.459  1.560  1.673  1.796  1.927 2.064  2.205 ];
% Annual CS coefficients from 2 to 20 years. Fill one-year yield with spline
CSemp = [ -0.047  -0.247  -0.352  -0.432  -0.498  -0.554  -0.606  -0.655  -0.705  -0.757  -0.814  -0.877  -0.945  -1.018  -1.098  -1.181  -1.269  -1.360  -1.454 ];
% Unconditional volatility of yields from 2 to 20 years.  
Volemp = [ 1.593  1.557  1.529  1.494  1.453  1.410  1.368  1.328  1.292  1.259  1.229  1.203  1.180  1.159  1.141  1.125  1.111  1.099  1.087 ];
% Unconditional volatility of monthly yield changes from 2 to 20 years
DVolemp = [ 1.498 1.123	0.985	0.910	0.857	0.815	0.779	0.749	0.722	0.699	0.679	0.661	0.646	0.633	0.623	0.615	0.610	0.607	0.607 ];
% Unconditional volatility of annual yield changes from 2 to 20 years
DVolempa = [ 1.234	1.002	0.891	0.822	0.770	0.727	0.691	0.658	0.630	0.605	0.584	0.565	0.549	0.535	0.524	0.515	0.508	0.502	0.498 ];
% Unconditional correlations for two-year bond from 2 to 20 years
Correlemp = [ 1.000	0.976	0.942	0.914	0.892	0.873	0.857	0.843	0.830	0.818	0.807	0.796	0.786	0.777	0.769	0.761	0.754	0.748	0.742 ];
% Unconditional correlations of monthly yield changes for two-year bond, from 2 to 20 years
DCorrelemp = [ 1.000	0.925	0.821	0.751	0.709	0.680	0.656	0.634	0.611	0.588	0.564	0.539	0.515	0.492	0.470	0.451	0.433	0.418	0.405 ];
% Unconditional correlations of annual yield changes for two-year bond, from 2 to 20 years
DCorrelempa = [ 1.000	0.963	0.899	0.840	0.790	0.749	0.712	0.680	0.650	0.623	0.597	0.573	0.550	0.528	0.508	0.490	0.474	0.459	0.447 ];
% Fraction of annual yield changes explained by first principal component
explainedDyemp(1) = 85.2496;
% First principal component of annual yield changes
scaledpc1Dyemp = [  1.0000    0.9107    0.8496    0.7997    0.7550    0.7133    0.6742    0.6378    0.6041    0.5733    0.5454    0.5204    0.4983    0.4788    0.4620    0.4475    0.4352    0.4250    0.4167 ];


% % Solve for M
% 
% % Initial condition, method 1 (sib=0)
% 
% options=optimset('MaxFunEvals',100000,'MaxIter',10000,'Display','off');
% 
% hkr = fzero(@Hkr,kr,options);
% 
%     function F = Hkr(x)
% 
% F = x-kr-aalx*sir*Fint(x,x,dalx);
% 
%      end
% 
% x01 = Fint(hkr,hkr,dalx);
% 
% % zb is coefficient of bt when sib=0 and kb=0
% 
% zb = athx*sir*Hint(hkr,dalx,dthx)/(1+aalx*sir*(Gint(hkr,dalx)-Fint(hkr,hkr,dalx))/hkr);
% 
% % Itau2 = int_0^T tau^2*exp(-dalx*tau)*dtau
% 
% Itau2 = 2/dalx^3*(1-exp(-dalx*T)-dalx*T*exp(-dalx*T)-dalx^2*T^2/2*exp(-dalx*T));
% 
% x02 = (zb/hkr)^2*(Itau2 - 2*Gint(hkr,dalx) + Fint(hkr,hkr,dalx));
% 
% x03 = zb/hkr*(Gint(hkr,dalx)-Fint(hkr,hkr,dalx));
% 
% x04 = Hint(hkr,dalx,dthx);
% 
% % DItau1 = int_0^T tau*(exp(-dalx*tau)-exp(-dthx*tau))*dtau
% 
% DItau1 = 1/dalx^2*(1-exp(-dalx*T)-dalx*T*exp(-dalx*T))-1/dthx^2*(1-exp(-dthx*T)-dthx*T*exp(-dthx*T));
% 
% x05 = zb/hkr*(DItau1 - Hint(hkr,dalx,dthx));
% 
% M011 = kr+aalx*sir*x01;
% 
% M012 = aalx*sib*x03 ;
% 
% M021 = -sir*(athx*x04-aalx*x03);
% 
% M022 = kbx-sib*(athx*x05-aalx*x02);


% Initial condition, method 2 (aal=0)

options=optimset('MaxFunEvals',100000,'MaxIter',10000,'Display','off');

Hkbloc = @(x)Hkb(x,kbx,aalx,athx,dalx,dthx);
                      
[hkb,fval,exitflag] = fsolve(Hkbloc,kbx,options);

ZAb = sir*athx*Hint(kr,dalx,dthx)/(1+sir*aalx*(Fint(kr,kr,dalx)-Fint(kr,hkb,dalx))/(hkb-kr));

M011 = kr+sir*aalx*Fint(kr,kr,dalx);

M012 = sib*aalx*ZAb*(Fint(kr,kr,dalx)-Fint(kr,hkb,dalx))/(hkb-kr);

M021 = -sir*(athx*Hint(kr,dalx,dthx)-aalx*ZAb*(Fint(kr,kr,dalx)-Fint(kr,hkb,dalx))/(hkb-kr));

M022 = kbx-sib*ZAb*(athx*(Hint(kr,dalx,dthx)-Hint(hkb,dalx,dthx))-aalx*ZAb*(Fint(kr,kr,dalx)+Fint(hkb,hkb,dalx)-2*Fint(kr,hkb,dalx))/(hkb-kr))/(hkb-kr);      


% Solve non-linear system

M0 = [ M011 M012 M021 M022 ];

options=optimset('MaxFunEvals',100000,'MaxIter',10000,'Display','off');

MmatlocSSR = @(M)Mmat(M,kbx,aalx,athx,dalx,dthx);
                      
[M,fval,exitflag] = fsolve(MmatlocSSR,M0,options);


if exitflag < 1
    
    F = 1e6;
    
else

Mm = [ M(1)    M(2)  ; 
      M(3)    M(4) ] ;
        
L = eig(Mm);

la1 = L(1);

la2 = L(2);

ph1= -(M(1)-la1)/M(3);

ph2= -(M(1)-la2)/M(3);

eigvalues = [la1 la2];
eigvector1 = [1 ph1];
eigvector2 = [1 ph2];

% Display

% disp(['Eigenvalues     = ',num2str(eigvalues)]);
% disp(['Eigenvector 1     = ',num2str(eigvector1)]);    
% disp(['Eigenvector 2     = ',num2str(eigvector2)]); 

% Curves

% coefs in Ar

cAr1 = -ph2/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAr2 = ph1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

% coefs in Ab

cAb1 = 1/(ph1-ph2); %coef of (1-exp(-la1*tau))/la1

cAb2 = -1/(ph1-ph2); %coef of (1-exp(-la2*tau))/la2

Th=T+0.5;
Ttwo=2*T+1;

tau = 0.00001 : 0.5 : Th;

Ar = cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2;

Ab = cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2;

Arb = (cAr1*(1-exp(-la1*tau))/la1 + cAr2*(1-exp(-la2*tau))/la2)./tau;

Abb = (cAb1*(1-exp(-la1*tau))/la1 + cAb2*(1-exp(-la2*tau))/la2)./tau;


% Fama-Bliss

sirunc = sir/2/kr;
sibunc = sib/2/kbx;

Dn=3;
Dt=0.5*(Dn-1);

for n=Dn+1 : 1 : Ttwo
    n1=n-Dn+1;
    FBnum(1,n-Dn)=(Ar(n)-Ar(n1)*exp(-kr*Dt)-Ar(Dn))*(Ar(n)-Ar(n1)-Ar(Dn))*sirunc+(Ab(n)-Ab(n1)*exp(-kbx*Dt)-Ab(Dn))*(Ab(n)-Ab(n1)-Ab(Dn))*sibunc;
    FBden(1,n-Dn)=(Ar(n)-Ar(n1)-Ar(Dn))^2*sirunc+(Ab(n)-Ab(n1)-Ab(Dn))^2*sibunc;
    FB(1,n-Dn)=FBnum(1,n-Dn)/FBden(1,n-Dn);
end

tauFB = Dt+0.5+0.00001 : 0.5 : Th;


% Campbell-Shiller

CS = zeros(Ttwo,Ttwo);

for n2 = 2 : 1 : Ttwo
    for n1 = 2 : 1 : n2-1
        
        n3=n2-n1+1;  
        tau1 = 0.5*(n1-1);
        tau2 = 0.5*(n2-1);
        tau3 = tau2-tau1;
        CSdepr = Ar(n3)/tau3*exp(-kr*tau1)-Ar(n2)/tau2;
        CSdepb = Ab(n3)/tau3*exp(-kbx*tau1)-Ab(n2)/tau2;
        CSindr = tau1/tau3*(Ar(n2)/tau2-Ar(n1)/tau1);
        CSindb = tau1/tau3*(Ab(n2)/tau2-Ab(n1)/tau1);
        CS(n1,n2)=(CSdepr*CSindr*sirunc+CSdepb*CSindb*sibunc)/(CSindr^2*sirunc+CSindb^2*sibunc); 

    end
end

tauCS3 = 1.5+0.00001 : 0.5 : Th;


% Volatility of yields

Vol = 100*(sirunc*Ar.^2+sibunc*Ab.^2).^0.5./tau;


% Volatility of monthly yield changes

DVol = 100*(24*(sirunc*(1-exp(-kr/12))*Ar.^2+sibunc*(1-exp(-kbx/12))*Ab.^2)).^0.5./tau;


% Volatility of annual yield changes

DVola = 100*(2*(sirunc*(1-exp(-kr))*Ar.^2+sibunc*(1-exp(-kbx))*Ab.^2)).^0.5./tau;


% Correlation matrix

Correl = 100^2*(sirunc*(Ar./tau).'*(Ar./tau)+sibunc*(Ab./tau).'*(Ab./tau))./(Vol.'*Vol);


% Correlation matrix of monthly yield changes 

DCorrel = 100^2*24*(sirunc*(1-exp(-kr/12))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kbx/12))*(Ab./tau).'*(Ab./tau))./(DVol.'*DVol);


% Correlation matrix of annual yield changes 

DCorrela = 100^2*2*(sirunc*(1-exp(-kr))*(Ar./tau).'*(Ar./tau)+sibunc*(1-exp(-kbx))*(Ab./tau).'*(Ab./tau))./(DVola.'*DVola);


% Principal components

CovMR = sir*Ar(5:41)'*Ar(5:41) + sib*Ab(5:41)'*Ab(5:41);

[pcR,latentR,explainedR] = pcacov(CovMR);

scaledpc1R = pcR(:,1)./(tau(5:41)')/pcR(1,1);

% disp(['explainedR(1)     = ',num2str(explainedR(1))]);    
% disp(['explainedR(2)     = ',num2str(explainedR(2))]);

CovMDy = sirunc*(1-exp(-kr/12))*(Ar(5:41)./tau(5:41)).'*(Ar(5:41)./tau(5:41))+sibunc*(1-exp(-kbx/12))*(Ab(5:41)./tau(5:41)).'*(Ab(5:41)./tau(5:41));

[pcDy,latentDy,explainedDy] = pcacov(CovMDy);

scaledpc1Dy = pcDy(:,1)'/pcDy(1,1);

% disp(['explainedDy(1)     = ',num2str(explainedDy(1))]);    
% disp(['explainedDy(2)     = ',num2str(explainedDy(2))]);  


FitFB = (mean(FB(2:38))-mean(FBemp))^2;

FitCS = (mean(CS(3,5:41))-mean(CSemp))^2;

FitFBCS = (abs(mean(FB(2:38)))+abs(mean(CS(3,5:41)))-abs(mean(FBemp))-abs(mean(CSemp)))^2;

FitVol = (mean(Vol(5:41))-mean(Volemp))^2;

FitDVol = (mean(DVol(5:41))-mean(DVolemp))^2;

FitDVola = (mean(DVola(5:41))-mean(DVolempa))^2;

FitCorrel = (mean(Correl(5,5:41))-mean(Correlemp))^2;

FitDCorrel = (mean(DCorrel(5,5:41))-mean(DCorrelemp))^2;

FitDCorrela = (mean(DCorrela(5,5:41))-mean(DCorrelempa))^2;

FitExplained = (explainedDy(1) - explainedDyemp(1))^2;

FitPC1 = (scaledpc1Dy(37) - scaledpc1Dyemp(19))^2;




F = 0*FitFB + 0*FitCS + 0*FitFBCS + FitVol + 0*FitDVol + FitDVola + 0*FitCorrel + 0*FitDCorrel + FitDCorrela + 0*FitExplained + 0*FitPC1;


% disp(['FitFB     = ',num2str(FitFB)]);
% disp(['FitCS     = ',num2str(FitCS)]);
% disp(['FitVol     = ',num2str(FitVol)]);
% disp(['FitDVol     = ',num2str(FitDVol)]);
% disp(['FitDVola     = ',num2str(FitDVola)]);
% disp(['FitCorrel     = ',num2str(FitCorrel)]);
% disp(['FitDCorrel     = ',num2str(FitDCorrel)]);
% disp(['FitDCorrela     = ',num2str(FitDCorrela)]);
% disp(['Fit     = ',num2str(F)]);

end

end

